@@ -1,5 +1,7 @@
 hmd.DA.mx <-
 function(data, sex="female"){
+	
+	
 	if(is.matrix(data)){
 		age.groups <- ncol(data)
 		} else age.groups <- length(data)
@@ -12,11 +14,12 @@ function(data, sex="female"){
 		lt.m0.xp <- t(log(flt.mx)[1:age.groups,])
 		}
 		
-	hmd.m0.train <- mclustDAtrain(data=lt.m0.xp, labels=class5)
-	hmd.m0.test <- mclustDAtest(data=data, models=hmd.m0.train)
-	classification <- summary(hmd.m0.test)$classification
+	hmd.m0.train <- MclustDA(data=lt.m0.xp, class=class5)
+	hmd.m0.test <- predict(hmd.m0.train, newdata=data)
+	out.dens <- hmd.m0.test$z
+	classification <- hmd.m0.test$classification
 	
-	return(list(train=hmd.m0.train, test=hmd.m0.test, classification=classification))
+	return(list(train=hmd.m0.train, out.dens=out.dens, classification=classification))
 	
 	}
 
